@@ -75,7 +75,7 @@
 #' @references
 #' Grassi M, Palluzzi F, Tarantino B (2022). SEMgraph: An R Package for Causal Network
 #' Analysis of High-Throughput Data with Structural Equation Models.
-#' Bioinformatics, 2022;, btac567, https://doi.org/10.1093/bioinformatics/btac567
+#' Bioinformatics, 38 (20), 4829–4830 <https://doi.org/10.1093/bioinformatics/btac567>
 #'
 #' Fisher RA (1915). Frequency Distribution of the Values of the Correlation
 #' Coefficient in Samples from an Indefinitely Large Population. Biometrika,
@@ -103,7 +103,7 @@ weightGraph<- function(graph, data, group = NULL, method = "r2z", limit = 10000,
 	ig <- induced_subgraph(graph, vids = which(V(graph)$name %in% nodes))
 	ig <- quiet(properties(ig)[[1]])
 	degree <- igraph::degree(ig, v = V(ig), mode = "all")
-	ftm <- as_data_frame(ig)
+	ftm <- igraph::as_data_frame(ig)
 	Y <- scale(data[, nodes])
 	if (is.null(group) | method == "r2z")
 		ew <- ew.r2z(ftm, Y, group)
